# panpdf

[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Python Version][python-v-image]][python-v-link]
[![Build Status][GHAction-image]][GHAction-link]
[![Coverage Status][codecov-image]][codecov-link]

panpdf is a versatile PDF documentation generator that
transforms Markdown files into beautifully formatted PDF
documents using Pandoc.

panpdf can extract figures and source code from Jupyter
notebooks.

It offers customizable headers, footers, and table of contents,
along with support for inserting figures and tables.

<!-- Badges -->
[pypi-v-image]: https://img.shields.io/pypi/v/panpdf.svg
[pypi-v-link]: https://pypi.org/project/panpdf/
[python-v-image]: https://img.shields.io/pypi/pyversions/panpdf.svg
[python-v-link]: https://pypi.org/project/panpdf
[GHAction-image]: https://github.com/daizutabi/panpdf/actions/workflows/ci.yml/badge.svg?branch=main&event=push
[GHAction-link]: https://github.com/daizutabi/panpdf/actions?query=event%3Apush+branch%3Amain
[codecov-image]: https://codecov.io/github/daizutabi/panpdf/coverage.svg?branch=main
[codecov-link]: https://codecov.io/github/daizutabi/panpdf?branch=main
